ArrowIpcTypes

Enum ArrowIpcTypes 

pub enum ArrowIpcTypes {
    UserInitData,
    Details,
    Stats,
    Upgrades,
    UnitBorn,
    UnitDied,
    MessageEvents,
    CmdTargetPoint,
    CmdTargetUnit,
    All,
}
The supported Arrow IPC types

Variants



UserInitData

Writes the crate::init_data::UserInitDataFlatRow flat row to an Arrow IPC file



Details

Writes the crate::details::PlayerLobbyDetailsFlatRow flat row to an Arrow IPC file



Stats

Writes the crate::tracker_events::PlayerStatsEvent to an Arrow IPC file



Upgrades

Writes the crate::tracker_events::UpgradeEvent to an Arrow IPC file



UnitBorn

Writes the crate::tracker_events::UnitBornEvent to an Arrow IPC file



UnitDied

Writes the crate::tracker_events::UnitDiedEvent to an Arrow IPC file



MessageEvents

Writes the crate::message_events::MessageEvent to an Arrow IPC file



CmdTargetPoint

Writes the crate::game_events::CmdTargetPointEventFlatRow to an Arrow IPC file



CmdTargetUnit

Writes the crate::game_events::CmdTargetUnitEventFlatRow to an Arrow IPC file



All

Writes all the implemented flat row types to Arrow IPC files inside the output directory

Implementations

Source

impl ArrowIpcTypes

pub fn schema(&self) -> Schema

Returns the schema for the chosen output type

pub fn handle_write_snapshot( sources: Vec<InitData>, output: PathBuf, unit_abilities: &HashMap<(u32, String), VersionedBalanceUnit>, serially: bool, ) -> Result<(), Box<dyn Error>>

Writes a snapshot of the replay collection. A snapshot is a collection of generated files that work together. The consistency of the files is not yet implemented. But the files should have been generated at around the same time. If one file lags behind, it may be from an incomplete data generation. i.e. this function is called but it errors in the middle and no retries/fixes are done. Two things todo: First delete all the files in the snapshot directory. Add a snashopt generation timestamp and when reads are done, they are checked for very basic timestamp write consistency.

pub fn handle_tracker_events( &self, sources: Vec<InitData>, output: PathBuf, versioned_abilities: &HashMap<(u32, String), VersionedBalanceUnit>, serially: bool, ) -> Result<(), Box<dyn Error>>

Creates a new Arrow IPC file with the tracker events data This seems to be small enough to not need to be chunked and is done in parallel This requires 1.5GB of RAM for 3600 files, so maybe not good for real players.

pub fn handle_game_events( &self, sources: Vec<InitData>, output: PathBuf, versioned_abilities: &HashMap<(u32, String), VersionedBalanceUnit>, serially: bool, ) -> Result<(), Box<dyn Error>>

Creates a new Arrow IPC file with the game events data This requires 1.5GB of RAM for 3600 files, so maybe not good for real players.

pub fn handle_read_once_write_all( &self, sources: Vec<InitData>, output: PathBuf, ) -> Result<(), Box<dyn Error>>

Creates a new Arrow IPC file with the details data

pub fn handle_details_ipc_cmd( &self, sources: Vec<InitData>, output: PathBuf, ) -> Result<(), Box<dyn Error>>

Creates a new Arrow IPC file with the details data

pub fn handle_arrow_ipc_cmd( source: PathBuf, output: PathBuf, cmd: &WriteArrowIpcProps, unit_abilities: &HashMap<(u32, String), VersionedBalanceUnit>, serially: bool, ) -> Result<(), Box<dyn Error>>

Handles the Arrow IPC command variants