write_batches

Function write_batches 

pub fn write_batches(
    path: PathBuf,
    schema: Schema,
    chunk: RecordBatch,
) -> Result<(), Box<dyn Error>>
Converts the data into an Arrow IPC file, this is useful for small batches of data, for example if we are reading all the details from all the files, they should fit in memory (famous last words)