pub fn parse_packed_int(
input: (&[u8], usize),
offset: i64,
num_bits: usize,
) -> S2ProtoResult<(&[u8], usize), i64>Expand description
Reads a packed int, In offset binary representation, (also called excess-K or biased). a signed number is represented by the bit pattern corresponding to the unsigned number plus K, with K being the biasing value or offset.