convert_tracker_loop_to_seconds

Function convert_tracker_loop_to_seconds 

pub fn convert_tracker_loop_to_seconds(tracker_replay_loop: i64) -> u32
Converts the tracker loop to milliseconds, First scale the tracker loop to the same unit as the game loops. We also need to transform the adjusted game loop to seconds. This was observed in a game with max game_loop = 13735 and a duration of 15:42 = 942 seconds. 942000 / 13735 = 68.58391 loops in a second This will only work for the Faster speed.