Nom Parsing The S2 Protocol Version This is stored in the MPQ UserData Section and can be decoded with any Protocol Version Decoder. In the original code, in s2protocol from Blizzard, each protocol version has its own version decoder. and whatever protocol is latest would decoded the target file. In this verison we are not yet doing that but we should.
Structs
- Protocol
Header - The S2 Protocol Header
Functions
- read_
protocol_ header - Read the protocol header, this can be read with any protocol