pub struct SC2ReplayState {
pub init_data: InitData,
pub details: Details,
pub units: HashMap<u32, SC2Unit>,
pub user_state: HashMap<i64, SC2UserState>,
pub balance_units: VersionedBalanceUnits,
}Expand description
The state of the replay as it’s being processed, units are added to owners, control groups are updated, unit position recorded, etc.
Fields
init_data: InitDataThe parsed replay.initData from the MPQ, used to get further information about the players, protocol version, map size, observe, user_id (can be used to match between different event typse)
details: DetailsThe parsed replay.details from the MPQ, used to get information on the players
units: HashMap<u32, SC2Unit>The registered units state as they change through time. These are with unit index as reference
user_state: HashMap<i64, SC2UserState>The per-user state, the control groups, the supply, units, upgrades, as it progresses through time.
balance_units: VersionedBalanceUnitsThe current protocol version abilities, containing a possible string translation.
Implementations
Sourceimpl SC2ReplayState
impl SC2ReplayState
pub fn with_balance_units( self, balance_units: HashMap<String, VersionedBalanceUnit>, ) -> Self
Sourcepub fn handle_transition_to_next_event(
&mut self,
event: SC2EventType,
) -> SC2EventIteratorItem
pub fn handle_transition_to_next_event( &mut self, event: SC2EventType, ) -> SC2EventIteratorItem
When an event is meant to be consumed (i.e. it’s the next in order), then the state of the game needs to transition through the event, returning a Hint of what has changed.